@@ -19,7 +19,7 @@ require 'ctioga2/commands/strings'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 151 $', '$Date: 2010-06-19 23:45:20 +0200 (Sat, 19 Jun 2010) $')
+  Version::register_svn_info('$Revision: 327 $', '$Date: 2012-11-28 14:47:52 +0100 (Wed, 28 Nov 2012) $')
 
   module Commands
 
@@ -70,6 +70,9 @@ module CTioga2
         def parse_io_object(io, interpreter)
           # The process is simple: we look for symbols and
           # corresponding syntax element: parentheses or assignments
+
+          ## @todo It would be really great if assignments could be
+          ## made conditional (a bit like in makefiles)
           while(1)
             symbol = up_to_next_symbol(io)
             break if not symbol
@@ -107,6 +110,7 @@ module CTioga2
                   end
                 end
 
+                interpreter.context.parsing_file(symbol, io) # Missing line number
                 interpreter.run_command(cmd, real_args, options)
                 io.getc         # Slurp up the )
                 break
