@@ -25,7 +25,7 @@ require 'ctioga2/data/filters'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 233 $', '$Date: 2011-01-20 10:26:42 +0100 (Thu, 20 Jan 2011) $')
+  Version::register_svn_info('$Revision: 367 $', '$Date: 2012-12-28 16:14:52 +0100 (Fri, 28 Dec 2012) $')
 
 
   module Data
@@ -80,8 +80,14 @@ module CTioga2
       def get_datasets(set, options = {})
         backend = @backend_factory.current
         sets = backend.expand_sets(set)
-        datasets = sets.map do |s|
-          backend.dataset(s)
+        datasets = []
+        for s in sets
+          begin
+            datasets << backend.dataset(s)
+          rescue Exception => e
+            error { "Could not load dataset #{s} -- #{e}" }
+            debug { "#{e.backtrace.join("\n")}" }
+          end
         end
         add_datasets(datasets, options)
         return datasets
@@ -157,6 +163,25 @@ module CTioga2
         end
       end
 
+      # Returns a list of datasets, either a named dataset, or the
+      # last datasets from the stack
+      def latest_datasets(opts)
+        if opts['which']
+          if opts['number']
+            warn { "Cannot use both which and number" }
+          end
+          datasets = [ specified_dataset(opts) ]
+        else
+          nb = opts['number'] || 2
+          if @stack.size < nb
+            raise "Not enough datasets on the stack"
+          end
+          datasets = @stack[(- nb).. -2]
+          datasets.reverse!
+        end
+      end
+        
+        
       # Appends a set of commands to the dataset hook
       def add_to_dataset_hook(commands)
         if @dataset_hook
@@ -176,25 +201,25 @@ module CTioga2
         end
       end
 
-      # Pops the last _n_ datasets off the stack and pushes back the
-      def concatenate_datasets(n = 2)
+      # Add all the given datasets to the current one.
+      def concatenate_datasets(datasets, name = nil)
         ds = @stack.pop
         raise "Nothing on the stack" unless ds
-        (n-1).times do
-          ds2 = @stack.pop
-          raise "Not enough datasets on the stack" unless ds2
+
+        for ds2 in datasets
           ds << ds2
         end
         @stack.push(ds)
+        # Name the dataset
+        @named_datasets[name] = ds if name
       end
 
-      # Merges the last datasets into a new one.
+      # Merges one or more datasets into the last one.
       #
-      # Over
-      def merge_datasets(n = 2, columns = [0], precision = nil)
+      # The last dataset of the stack is overwritten.
+      def merge_datasets_into_last(datasets, columns = [0], precision = nil)
         ds = @stack.pop
         raise "Nothing on the stack" unless ds
-        datasets = @stack[-1..-(n-1)]
         ds.merge_datasets_in(datasets, columns, precision)
         @stack.push(ds)
       end
@@ -204,6 +229,32 @@ module CTioga2
         return @stack.last
       end
 
+      # Displays the contents of the stack
+      def show
+        STDERR.puts "Stack contents"
+        i = 0
+        # Swap the named dataset stuff
+        ## @todo Maybe a hash pair should be maintained in permanence ?
+        rev = {}
+        for k,v in @named_datasets
+          rev[v] = k
+        end
+
+        for ds in @stack
+          name = rev[ds]
+          if name
+            name = "(named: '#{name}')"
+          else
+            name = ""
+          end
+          
+          pref = sprintf("#%-2d %-3d:", i, - @stack.size + i)
+          
+          STDERR.puts " * #{pref} #{ds.name} -- #{ds.ys.size + 1} columns #{name}"
+          i += 1
+        end
+      end
+
       
     end
 
@@ -284,31 +335,82 @@ onto the stack, or the given stored dataset if the which option is given.
 EOH
 
     ConcatLastCommand = 
-      Cmd.new("join-datasets", nil, "--join-datasets", 
-              [], {'number' => CmdArg.new('integer')}) do |plotmaker, opts|
-      nb = opts['number'] || 2
-      plotmaker.data_stack.concatenate_datasets(nb)
+      Cmd.new("join-datasets", "-j", "--join-datasets", 
+              [], 
+              { 
+                'number' => CmdArg.new('integer'),
+                'which' => CmdArg.new('stored-dataset'),
+                'name' => CmdArg.new('text') 
+              }) do |plotmaker, opts|
+      stack = plotmaker.data_stack
+      datasets = stack.latest_datasets(opts)
+      stack.concatenate_datasets(datasets, opts['name'])
     end
     
     ConcatLastCommand.describe("Concatenates the last datasets on the stack",
                                <<EOH, DataStackGroup)
 Pops the last two (or number, if it is specified) datasets from the
 stack, concatenates them (older last) and push them back onto the
-stack.
+stack. The name option can be used to give a name to the new dataset. 
+EOH
+
+    ApplyLastCommand =
+      Cmd.new("apply-formula", nil, "--apply-formula",
+              [CmdArg.new('text')], 
+              {
+                'which' => CmdArg.new('stored-dataset'),
+                'name' => CmdArg.new('text'),
+              }) do |plotmaker, formula, opts|
+      ds = plotmaker.data_stack.specified_dataset(opts)
+      newds = ds.apply_formulas(formula)
+      plotmaker.data_stack.add_datasets([newds], opts)
+    end
+    
+    ApplyLastCommand.describe("Applies a formula to the last dataset",
+                              <<EOH, DataStackGroup)
+Applies a formula to the last dataset (or the named one)
+EOH
+
+    ShowStackCommand = 
+      Cmd.new("show-stack", nil, "--show-stack", 
+              [], 
+              { }
+              ) do |plotmaker, opts|
+      plotmaker.data_stack.show
+    end
+    
+    ShowStackCommand.describe("Displays the content of the stack",
+                              <<EOH, DataStackGroup)
+Displays the current contents of the dataset stack. 
+
+Mostly used for debugging when operations like {command: merge-datasets}
+or {command: join-datasets} don't work as expected.
 EOH
 
 
+    ## @todo Add column selection ?
     MergeToLastCommand = 
       Cmd.new("merge-datasets", nil, "--merge-datasets", 
-              [], {'number' => CmdArg.new('integer')}) do |plotmaker, opts|
-      nb = opts['number'] || 2
-      ## @todo all
-      plotmaker.data_stack.merge_datasets(nb)
+              [], 
+              {
+                'number' => CmdArg.new('integer'), 
+                'which' => CmdArg.new('stored-dataset')
+              }
+              ) do |plotmaker, opts|
+      stack = plotmaker.data_stack
+      datasets = stack.latest_datasets(opts)
+      plotmaker.data_stack.merge_datasets_into_last(datasets)
     end
     
-    MergeToLastCommand.describe("....",
-                               <<EOH, DataStackGroup)
-....
+    MergeToLastCommand.describe("Merge datasets based on X column",
+                                <<EOH, DataStackGroup)
+This commands merges data with matching X values from a dataset (by
+default the one before the last) into the last one. Data points that
+have no corresponding X value in the current dataset are simply
+ignored.
+
+This can be used to build 3D datasets for {cmd: xyz-map} or 
+{cmd: xy-parametric}.
 EOH
 
     XYReglinCommand = 
@@ -325,7 +427,31 @@ EOH
     
     XYReglinCommand.describe("....",
                              <<EOH, DataStackGroup)
-....
+...
+
+This command will get documented some day.
+EOH
+
+
+    ComputeContourCommand = 
+      Cmd.new("compute-contour", nil, "--compute-contour", 
+              [CmdArg.new("float")], {
+                'which' => CmdArg.new('stored-dataset')
+              }) do |plotmaker, level, opts|
+      stack = plotmaker.data_stack
+      ds = stack.specified_dataset(opts)
+      f = ds.make_contour(level)
+      newds = Dataset.new("Contour #{level}", [f.x, f.y])
+      stack.store_dataset(newds, true)
+    end
+    
+    ComputeContourCommand.describe("computes the contour and push it to data stack",
+                             <<EOH, DataStackGroup)
+Computes the contour at the given level for the given dataset (or the
+last on the stack if none is specified) and pushes it onto the data
+stack.
+
+You can further manipulate it as usual.
 EOH
 
     SetDatasetHookCommand = 
