@@ -16,7 +16,7 @@ require 'ctioga2/log'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 285 $', '$Date: 2011-02-22 21:12:47 +0100 (Tue, 22 Feb 2011) $')
+  Version::register_svn_info('$Revision: 329 $', '$Date: 2012-12-11 00:13:17 +0100 (Tue, 11 Dec 2012) $')
 
   module Graphics
 
@@ -103,8 +103,14 @@ module CTioga2
         # Makes up a Boundaries object from two axes keys
         def get_given_boundaries(horiz, vert)
           if @computed_boundaries
-            return Types::Boundaries.from_ranges(@computed_boundaries[horiz],
-                                                 @computed_boundaries[vert])
+            if @computed_boundaries.key?(horiz) and 
+                @computed_boundaries.key?(vert)
+              return Types::Boundaries.from_ranges(@computed_boundaries[horiz],
+                                                   @computed_boundaries[vert])
+            else
+              error { "A subplot element doesn't have inner bounds -- which probably means that no curves were defined" }
+              return Types::Boundaries.new(0.0,1.0,0.0,1.0)
+            end
           else
             return nil
           end
