@@ -14,6 +14,8 @@
 require 'ctioga2/graphics/styles/base'
 
 require 'ctioga2/graphics/styles/drawable'
+require 'ctioga2/graphics/styles/arrows'
+require 'ctioga2/graphics/styles/box'
 require 'ctioga2/graphics/styles/location'
 require 'ctioga2/graphics/styles/texts'
 require 'ctioga2/graphics/styles/carrays'
@@ -36,3 +38,6 @@ require 'ctioga2/graphics/styles/legend'
 
 
 require 'ctioga2/graphics/styles/factory'
+
+# Style sheets
+require 'ctioga2/graphics/styles/sheet'
