@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 202 $', '$Date: 2010-11-30 22:21:17 +0100 (Tue, 30 Nov 2010) $')
+  Version::register_svn_info('$Revision: 357 $', '$Date: 2012-12-26 00:49:11 +0100 (Wed, 26 Dec 2012) $')
 
   module Graphics
 
@@ -33,36 +33,44 @@ module CTioga2
         # AXIS_WITH_TICKS_ONLY,
         # AXIS_WITH_MAJOR_TICKS_AND_NUMERIC_LABELS, and
         # AXIS_WITH_TICKS_AND_NUMERIC_LABELS.
-        attr_accessor :decoration
+        typed_attribute :decoration, 'axis-decoration'
         
         # The position of the axis. Can be one of :left, :right, :top,
         # :bottom, :at_y_origin or :at_x_origin.
-        attr_accessor :location
+        typed_attribute :location, 'location'
 
         # Offset of the axis with respect to its normal position. It
         # is counted *away* from the graph. It is either a
         # Types::Dimension object or _nil_.
-        attr_accessor :offset
+        typed_attribute :offset, 'dimension'
 
         # The background lines for the given axis. _nil_ for nothing,
         # or a StrokeStyle object if we want to draw something.
-        attr_accessor :background_lines
+        #
+        # @todo Use a sub-style for that when that is implemented.
+        sub_style :background_lines, StrokeStyle
 
         # The style of the tick labels
-        attr_accessor :tick_label_style
+        sub_style :tick_label_style, FullTextStyle, "tick_label_%s"
 
         # The label of the axis, if there is one
-        attr_accessor :axis_label
+        sub_style :axis_label, TextLabel
 
         # Whether the axis should be log scale or not
-        attr_accessor :log
+        typed_attribute :log, 'boolean'
 
         # Transform: a Types::Bijection object specifying a coordinate
         # transformation for the axis.
-        attr_accessor :transform
+        typed_attribute :transform, 'bijection'
 
         # The color of the stroke for the lines of the axis
-        attr_accessor :stroke_color
+        typed_attribute :stroke_color, 'color'
+
+        typed_attribute :major_tick_length, 'float'
+        typed_attribute :major_tick_width, 'float'
+
+        typed_attribute :minor_tick_length, 'float'
+        typed_attribute :minor_tick_width, 'float'
 
 
         # Creates a new AxisStyle object at the given location with
@@ -89,8 +97,14 @@ module CTioga2
           spec = get_axis_specification(t)
           # Add tick label style:
           spec.merge!(@tick_label_style.to_hash)
-          if @stroke_color
-            spec['stroke_color'] = @stroke_color
+
+          # Direct copy of attributes 
+          for key in %w(stroke_color major_tick_length major_tick_width
+minor_tick_length minor_tick_width)
+            val = self.send(key.to_sym)
+            if val
+              spec[key] = val
+            end
           end
           t.show_axis(spec)
           @axis_label.loc = @location
@@ -258,16 +272,9 @@ module CTioga2
        
       end
 
-      PartialAxisStyle = {
-        'transform' => CmdArg.new('bijection'),
-        'location' => CmdArg.new('location'),
-        'stroke_color' => CmdArg.new('color')
-      }
-
-      FullAxisStyle = PartialAxisStyle.dup
-      FullAxisStyle['decoration'] = CmdArg.new('axis-decoration')
-                       
-
+      AxisStyleOptions = AxisStyle.options_hash()
+      PartialAxisStyle = AxisStyleOptions.without('decoration')
+      
     end
   end
 end
