@@ -19,7 +19,7 @@ require 'ctioga2/graphics/coordinates'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 202 $', '$Date: 2010-11-30 22:21:17 +0100 (Tue, 30 Nov 2010) $')
+  Version::register_svn_info('$Revision: 370 $', '$Date: 2012-12-28 17:40:18 +0100 (Fri, 28 Dec 2012) $')
 
   module Graphics
 
@@ -33,6 +33,10 @@ module CTioga2
       # * ticks
       # * background (uniform fill + watermark if applicable + possibly
       #   a picture .?)
+      #
+      # This class is way too complex and needs too much flexibility
+      # to be handled by a subclass of BasicStyle. However, all
+      # substyles should be.
       class PlotStyle
 
         include Tioga::FigureConstants
@@ -55,6 +59,8 @@ module CTioga2
         attr_accessor :plot_margin
 
         # Coordinate tranforms
+        #
+        # @todo they should be axis-specific.
         attr_accessor :transforms
 
         # Style of the background of the plot
@@ -75,32 +81,48 @@ module CTioga2
         def initialize
           # Default style for the plots.
           @axes = {}
-          @axes[:left] = AxisStyle.new(:left, 
-                                       AXIS_WITH_TICKS_AND_NUMERIC_LABELS,
-                                       '$y$')
-          @axes[:bottom] = AxisStyle.new(:bottom, 
-                                         AXIS_WITH_TICKS_AND_NUMERIC_LABELS,
-                                         '$x$')
+          @axes[:left] = 
+            StyleSheet.style_for(AxisStyle, 'left', :left, 
+                                 AXIS_WITH_TICKS_AND_NUMERIC_LABELS,
+                                 '$y$')
+          @axes[:bottom] = 
+            StyleSheet.style_for(AxisStyle, 'bottom', :bottom, 
+                                 AXIS_WITH_TICKS_AND_NUMERIC_LABELS,
+                                 '$x$')
 
-          @axes[:right] = AxisStyle.new(:right, AXIS_WITH_TICKS_ONLY)
-          @axes[:top] = AxisStyle.new(:top, AXIS_WITH_TICKS_ONLY)
+          @axes[:right] = 
+            StyleSheet.style_for(AxisStyle, 'right', :right, 
+                                 AXIS_WITH_TICKS_ONLY)
+          @axes[:top] = 
+            StyleSheet.style_for(AxisStyle, 'top', :top, 
+                                 AXIS_WITH_TICKS_ONLY)
 
           @xaxis_location = :bottom
           @yaxis_location = :left
 
-          @title = TextLabel.new
-          @title.loc = Types::PlotLocation.new(:top)
+          @title = 
+            StyleSheet.style_for(TextLabel, 'title',
+                                 nil, 
+                                 Types::PlotLocation.new(:top))
 
           @plot_margin = nil
 
           @transforms = CoordinateTransforms.new
 
-          @background = BackgroundStyle.new
+          @background = 
+            StyleSheet.style_for(BackgroundStyle, 'background')
 
           # A padding of 4bp ? Why ?? Why not ?
           @padding = Types::Dimension.new(:bp, 4)
         end
 
+        # Apply (destructively) the current transformations to the
+        # given dataset
+        def apply_transforms!(dataset)
+          @transforms.transform_2d!(dataset)
+        end
+
+
         # Whether to use log scale for the given axis.
         #
         # Now the question is: how should that affect user-defined
@@ -218,7 +240,7 @@ module CTioga2
                 axis.draw_axis(t)
               rescue Exception => e
                 error { "Impossible to draw axis #{which}: #{e.message}" }
-                debug { "Full message: #{e.inspect}" }
+                debug { "Full message: #{e.inspect}\n#{e.backtrace.join("\n")}" }
               end
             end
           end
@@ -310,13 +332,12 @@ module CTioga2
                                "Axes and labels", "Axes and labels", 40)
 
 
-      
       AxisTypeCommands = []
       [:left, :right, :top, :bottom].each do |loc|
         AxisTypeCommands << 
           Cmd.new("#{loc}",nil,"--#{loc}", 
                   [
-                   CmdArg.new('axis-decoration'),
+                   AxisStyleOptions['decoration'],
                   ], PartialAxisStyle) do |plotmaker, dec, opts|
           style = AxisStyle.current_axis_style(plotmaker, loc)
           style.decoration = dec
@@ -327,14 +348,18 @@ module CTioga2
           describe("Sets the type of the #{loc} axis", 
                    <<"EOH", AxisGroup)
 Sets the type of the #{loc} axis.
+
+The options have the same meaning as for {command: define-axis-style},
+see that command for more information.
 EOH
+
       end
 
       AxisStyleCommand = 
           Cmd.new("axis-style",nil,"--axis-style", 
                   [
                    CmdArg.new('axis'),
-                  ], FullAxisStyle) do |plotmaker, which, opts|
+                  ], AxisStyleOptions) do |plotmaker, which, opts|
         style = AxisStyle.current_axis_style(plotmaker, which)
         style.set_from_hash(opts)
       end
@@ -342,8 +367,8 @@ EOH
         describe("Sets the style of the given axis", 
                  <<"EOH", AxisGroup)
 This command can be used to set various aspects of the style of the 
-given axis, through its various options:
- * decoration
+given axis, through its various options, which are documented in more details 
+in the {command: define-axis-style} command.
 EOH
 
       BackgroundLinesCommand = 
@@ -351,10 +376,9 @@ EOH
                 [
                  CmdArg.new('axis'), 
                  CmdArg.new('color-or-false')
-                ],{
-                  'style' => CmdArg.new('line-style'),
-                  'width' => CmdArg.new('float')
-                }) do |plotmaker, which, color, options|
+                ],
+                StrokeStyle.options_hash().without('color')
+                ) do |plotmaker, which, color, options|
         axis = AxisStyle.current_axis_style(plotmaker, which)
         if color
           style = {'color' => color}
@@ -379,7 +403,8 @@ EOH
       %w{x y}.each do |axis|
         labelcmd = Cmd.new("#{axis}label", "-#{axis}", 
                             "--#{axis}label", [ CmdArg.new('text') ],
-                            FullTextStyleOptions) do |plotmaker, label, options|
+                            TextLabel.options_hash().without('text')
+                           ) do |plotmaker, label, options|
           PlotStyle.current_plot_style(plotmaker).
             set_label_style("#{axis}_label", options, label)
         end
@@ -387,6 +412,8 @@ EOH
                           <<"EOH", AxisGroup)
 Sets the #{axis.upcase} label of the current plot.
 EOH
+
+        Commands::make_alias_for_option "#{axis}label", 'alignment', 'align', true
         
         nolabelcmd = Cmd.new("no-#{axis}label", nil, 
                              "--no-#{axis}label", []) do |plotmaker|
@@ -415,8 +442,10 @@ EOD
       end
 
       TitleLabelCommand = 
-        Cmd.new('title', '-t', '--title', [ CmdArg.new('text') ],
-                FullTextStyleOptions) do |plotmaker, label, options|
+        Cmd.new('title', '-t', '--title', 
+                [ CmdArg.new('text') ],
+                TextLabel.options_hash().without('text')
+                ) do |plotmaker, label, options|
         PlotStyle.current_plot_style(plotmaker).
           set_label_style('title', options, label)
       end
@@ -426,6 +455,8 @@ EOD
 Sets the title of the current plot.
 EOH
 
+      Commands::make_alias_for_option 'title', 'alignment', 'align', true
+
       NoTitleLabelCommand = 
         Cmd.new('no-title', nil, '--no-title', []) do |plotmaker|
         PlotStyle.current_plot_style(plotmaker).
@@ -492,6 +523,8 @@ EOH
         PlotStyle.current_plot_style(plotmaker).
           set_label_style(which, options)
       end
+
+      Commands::make_alias_for_option 'label-style', 'alignment', 'align', true
       
       LabelStyleCommand.describe("Sets the style of the given label", 
                                  <<"EOH", AxisGroup)
@@ -508,6 +541,7 @@ override the color using the /stroke_color option of
 greater.
 EOH
 
+
     end
   end
 end
