@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 197 $', '$Date: 2010-11-29 14:26:12 +0100 (Mon, 29 Nov 2010) $')
+  Version::register_svn_info('$Revision: 370 $', '$Date: 2012-12-28 17:40:18 +0100 (Fri, 28 Dec 2012) $')
 
   module Graphics
 
@@ -26,31 +26,36 @@ module CTioga2
       # The style of a text object. This class is suitable for
       # inclusion as a Hash to FigureMaker#show_axis, for the tick
       # labels.
+      #
+      # @todo alignement and justification are poor names. halign
+      # and/or valign would be better.
       class BaseTextStyle < BasicStyle
         
         # The angle of the text
-        attr_accessor :angle
+        typed_attribute :angle, 'float'
 
         # The 'shift' of the text. Only meaningful for axes and tick
         # labels, where the position of the text is specified using a
-        # side rather than a precise position
-        attr_accessor :shift
+        # side rather than a precise position. In frame coordinates ?
+        typed_attribute :shift, 'float'
 
         # The scale of the text
-        attr_accessor :scale
+        typed_attribute :scale, 'float'
 
         # The vertical alignment 
-        attr_accessor :alignement
+        typed_attribute :alignment, 'alignment'
 
         # The horizontal alignment
-        attr_accessor :justification
+        typed_attribute :justification, 'justification'
 
         # Draw the _text_ at the given location with the given style.
         # If _y_ is _nil_, then _x_or_loc_ is taken to be a location
         # (see FigureMaker#show_text).
         def draw_text(t, text, x_or_loc, y = nil, measure = nil)
-          dict = prepare_show_text_dict(text, x_or_loc, y, measure)
-          t.show_text(dict)
+          t.context do
+            dict = prepare_show_text_dict(text, x_or_loc, y, measure)
+            t.show_text(dict)
+          end
         end
 
         protected
@@ -83,38 +88,35 @@ module CTioga2
       # The style of a full text object.
       class FullTextStyle < BaseTextStyle
         # The color of the text
-        attr_accessor :color
+        typed_attribute :color, 'color'
 
         # The (horizontal) position with respect to a location. You'll
         # seldom need that.
-        attr_accessor :position
+        #
+        # @todo Maybe this needs to fo in TextLabel rather than here ?
+        typed_attribute :position, 'float'
       end
 
       # A hash that can be used as a base for optional arguments to
       # things that take texts.
-      FullTextStyleOptions = {
-        'angle' => CmdArg.new('float'),
-        'shift' => CmdArg.new('float'),
-        'scale' => CmdArg.new('float'),
-        'justification' => CmdArg.new('justification'),
-        'color' => CmdArg.new('color'),
-        'align' => CmdArg.new('alignment'),
-      }
+      FullTextStyleOptions = FullTextStyle.options_hash()
 
       # A label.
       class TextLabel < FullTextStyle
         # The text of the label. _nil_ or _false_ means there will be
         # no text displayed
-        attr_accessor :text
+        typed_attribute :text, "text"
         
         # The location of the label.
         #
         # @todo This will have to eventually use PlotLocation, as it
         # makes much more sense.
-        attr_accessor :loc
+        typed_attribute :loc, "location"
 
-        def initialize(text = nil)
+        def initialize(text = nil, loc = nil)
+          super()
           @text = text
+          @loc = loc
         end
         
         # Draw the label, if #text is not _nil_ or _false_.
@@ -159,10 +161,8 @@ module CTioga2
 
       end
 
-      # Same thing as FullTextStyleOptions, but also permits to
-      # override the #text part of the whole stuff..
-      FullTextLabelOptions = FullTextStyleOptions.dup
-      FullTextLabelOptions['text'] = CmdArg.new('text')
+
+      FullTextLabelOptions = TextLabel.options_hash()
 
 
 
@@ -171,44 +171,32 @@ module CTioga2
       # like that.
       class MarkerStringStyle < BasicStyle
         
-        MarkerOptions = {
-          'color' => 'color',
-          'stroke_color' => 'color',
-          'fill_color' => 'color',
-          'scale' => 'float',
-          'horizontal_scale' => 'float',
-          'vertical_scale' => 'float',
-          'angle' => 'float',
-          'justification' => 'justification',
-          'alignment' => 'alignment',
-        }
-
-
         # The angle of the text
-        attr_accessor :angle
+        typed_attribute :angle, 'float'
 
         # The scale of the text
-        attr_accessor :scale
+        typed_attribute :scale, "float"
 
         # The horizontal scale of the text
-        attr_accessor :horizontal_scale
+        typed_attribute :horizontal_scale, "float"
 
         # The vertical scale of the text
-        attr_accessor :vertical_scale
+        typed_attribute :vertical_scale, "float"
 
         # The vertical alignment 
-        attr_accessor :alignement
+        typed_attribute :alignment, "alignment"
 
         # The horizontal alignment
-        attr_accessor :justification
+        typed_attribute :justification, "justification"
 
         # Colors
-        attr_accessor :color
-        attr_accessor :stroke_color
-        attr_accessor :fill_color
+        typed_attribute :color, 'color-or-false'
+        typed_attribute :stroke_color, 'color-or-false'
+        typed_attribute :fill_color, 'color-or-false'
+
 
         # A number between 1 to 14 -- a PDF font
-        attr_accessor :font
+        typed_attribute :font, "pdf-font"
 
         # The rendering mode.
         attr_accessor :mode
@@ -226,8 +214,14 @@ module CTioga2
           dict = self.to_hash
           dict['text'] = text
           dict['at'] = [x, y]
-          # TODO !
-          dict['mode'] = 
+          t.show_marker(dict)
+        end
+
+        # Draws the string marker at the given location
+        def draw_marker(t, marker, x, y)
+          dict = self.to_hash
+          dict['marker'] = marker
+          dict['at'] = [x, y]
           t.show_marker(dict)
         end
 
@@ -237,19 +231,6 @@ module CTioga2
         end
       end
       
-      StringMarkerOptions = {
-        'color' => CmdArg.new('color'),
-        'stroke_color' => CmdArg.new('color'),
-        'fill_color' => CmdArg.new('color'),
-        'scale' => CmdArg.new('float'),
-        'horizontal_scale' => CmdArg.new('float'),
-        'vertical_scale' => CmdArg.new('float'),
-        'angle' => CmdArg.new('float'),
-        'justification' => CmdArg.new('justification'),
-        'alignment' => CmdArg.new('alignment'),
-        'font' => CmdArg.new('pdf-font')
-      }
-
       # A LaTeX font. It should be applied to text using the function
       # #fontify.
       #
