@@ -25,7 +25,7 @@ require 'ctioga2/graphics/types/grid'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 249 $', '$Date: 2011-01-29 14:05:04 +0100 (Sat, 29 Jan 2011) $')
+  Version::register_svn_info('$Revision: 344 $', '$Date: 2012-12-23 22:45:22 +0100 (Sun, 23 Dec 2012) $')
 
   module Graphics
 
@@ -48,7 +48,6 @@ module CTioga2
 
     ColorType = CmdType.new('color', {
                               :type => :tioga_color,
-                              :namespace => Tioga::ColorConstants
                             }, <<EOD)
 A color. It can take three forms:
  * a named color, see 
@@ -61,7 +60,6 @@ EOD
     ColorOrFalseType = 
       CmdType.new('color-or-false', {
                     :type => :tioga_color,
-                    :namespace => Tioga::ColorConstants,
                     :shortcuts => {'none' => false }
                   }, <<EOD)
 A {type: color}, or false to say that nothing should be drawn.
