@@ -16,7 +16,7 @@ require 'ctioga2/log'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 198 $', '$Date: 2010-11-30 00:48:23 +0100 (Tue, 30 Nov 2010) $')
+  Version::register_svn_info('$Revision: 328 $', '$Date: 2012-11-28 15:11:49 +0100 (Wed, 28 Nov 2012) $')
 
   module Graphics
 
@@ -150,7 +150,7 @@ module CTioga2
             end
             return Dimension.new(unit, value, orientation)
           else
-            raise "Unkown Dimension specification: '#{text}'"
+            raise "Unknown Dimension specification: '#{text}'"
           end
         end
         
