@@ -102,6 +102,8 @@
 require 'ctioga2/utils'
 require 'ctioga2/log'
 
+CTioga2::Log::init_logger
+
 require 'shellwords'
 
 # Maybe, maybe, maybe... We need tioga ?
@@ -146,9 +148,14 @@ require 'ctioga2/postprocess'
 # * CTioga2::Data
 #
 # Have fun hacking...
+#
+# \section todo Various things and ideas...
+#
+# @li have a way to make one axis scale slave to another one (ie, for
+# displays of rate constants vs potentials)
 module CTioga2
 
-  Version::register_svn_info('$Revision: 244 $', '$Date: 2011-01-23 23:36:02 +0100 (Sun, 23 Jan 2011) $')
+  Version::register_svn_info('$Revision: 314 $', '$Date: 2012-08-10 11:59:35 +0200 (Fri, 10 Aug 2012) $')
 
   # This class is the core of ctioga. It parses the command-line arguments,
   # reads all necessary files and plots graphs. Most of its functionality
@@ -388,12 +395,6 @@ module CTioga2
         return
       end
       for set in sets
-        # We first trim elements from options that are not inside
-        # Graphics::Styles::CurveStyleFactory::PlotCommandOptions
-        options.delete_if { |k,v|
-          ! Graphics::Styles::
-          CurveStyleFactory::PlotCommandOptions.key?(k)
-        }
         add_curve(set, options)
       end
     end
@@ -442,6 +443,10 @@ module CTioga2
       raise "Duplicated option between PlotCommandOptions and LoadDatasetOptions"
     end
 
+    PlotOptions.merge!(Graphics::CurveGenerator::PlotOptions) do |key, oldval, newval| 
+      raise "Duplicated option between PlotCommandOptions and LoadDatasetOptions"
+    end
+
     PlotCommand = 
       Cmd.new("plot",nil,"--plot", 
               [ CmdArg.new('dataset') ], 
